#!/bin/bash
# This is a script to update the symlinks needed when serveral MTAs are
# installed at the same time.
# Erlend Midttun, <erlendbm at trustix dot org>

SBINFILES="sendmail newaliases"
BINFILES="mailq"
MAN1PAGES="newaliases sendmail mailq"
MAN5PAGES="aliases"

# Postfix is the default mailer unless /etc/sysconfig/mta says otherwise
MTA=postfix
test -f /etc/sysconfig/mta && . /etc/sysconfig/mta

pointsto () {
	if file $1 | grep -q $1-$2; then
		return 0
	else
		return 1
	fi
}

case "$1" in
	postfix|sendmail|exim)
		cd /usr/sbin
		for i in $SBINFILES; do
			ln -sf $i-$1 $i
		done
		cd /usr/bin
		for i in $BINFILES; do
			ln -sf $i-$1 $i
		done
		cd /usr/share/man/man1
		for i in $MAN1PAGES; do
			ln -sf $i-$1.1.gz $i.1.gz
		done
		cd /usr/share/man/man5
		for i in $MAN5PAGES; do
			ln -sf $i-$1.5.gz $i.5.gz
		done
	;;
	uninstall-postfix|uninstall-sendmail|uninstall-exim)
		INPUT=`echo $1 | sed -e 's|uninstall-||'`
		if [ "x$MTA" = "$INPUT" ]; then
			echo "Warning:  You are uninstalling the default MTA"
		fi
		cd /usr/sbin
		for i in $SBINFILES; do
			if pointsto $i $INPUT; then
				rm $i
			fi
		done
		cd /usr/bin
		for i in $BINFILES; do
			if pointsto $i $INPUT; then
				rm $i
			fi
		done
		cd /usr/share/man/man1
		for i in $MAN1PAGES; do
			if pointsto $i $INPUT; then
				rm $i.1.gz
			fi
		done
		cd /usr/share/man/man5
		for i in $MAN5PAGES; do
			if pointsto $i $INPUT; then
				rm $i.5.gz
			fi
		done
	;;
	*)
		echo "Usage: $0 postfix|sendmail|exim|uninstall-postfix|uninstall-sendmail|uninstall-exim"
		exit 1
	;;
esac

